USE [dgeMaterial_Sustain]
GO

/****** Object:  Trigger [dbo].[trgttMARA_AuditRecordIns]    Script Date: 6/1/2022 3:55:17 PM ******/
SET ANSI_NULLS ON
GO

SET QUOTED_IDENTIFIER ON
GO

CREATE   TRIGGER [dbo].[trgttMARA_AuditRecordIns]
   ON  [dbo].[ttMARA]
   AFTER Insert
AS
BEGIN
	/* Update the audit tables when a change is made */
	DECLARE @boaAuditProcessToken NVARCHAR(50),@boaAuditDateCreated DATETIME,@boaAuditUserID NVARCHAR(150),@boaAuditEvent NVARCHAR(50),@boaAuditID INT, @AddedVia NVARCHAR(50), @AddedBy NVARCHAR(50)
	CREATE TABLE #InsertOutput ([boaAuditID] int,[RequestID] int,[ZCounter] int)
	SET NOCOUNT ON;
	
	SELECT 
		@boaAuditDateCreated = GETDATE()
		,@boaAuditUserID = 'PageEventRule'		
		,@boaAuditEvent = 'Insert'
		,@AddedVia = [AddedVia] 
		,@AddedBy = [AddedBy] FROM INSERTED
		
/* Check if update occurs in the user interface and exit trigger if true.  Set the Audit UserID to the AddedVia field to capture stored procedure name*/
	IF (UPDATE([AddedVia]))
		--User Interface will record inserts in audit, exclude from trigger to avoid duplicates
		IF @AddedVia = 'UserInterface'
			RETURN
		--Excel Import will not record inserts in audit, include ExcelImport in records and use the AddedBy to record the user who has imported the records
		IF @AddedVia = 'ExcelImport'
			SET @boaAuditUserID = @AddedBy
		ELSE
			SET @boaAuditUserID = ISNULL(@AddedVia,@boaAuditUserID)
	
	-- We should be inserting a record into this table if this table is part of the Request. Request is tied to scenario and that scenario is tied to pages. 	
	-- If you just insert in the audit table then the review role aggregate code will break  

	DECLARE @boaAuditPageID UNIQUEIDENTIFIER
	
	SELECT TOP 1 @boaAuditPageID = Page.PageID
	FROM	INSERTED AS T 
		INNER JOIN dbo.ttRequest 
			ON T.RequestID = dbo.ttRequest.RequestID 
		INNER JOIN dbo.ttScenarioRoleTask 
			ON dbo.ttRequest.ScenarioID = dbo.ttScenarioRoleTask.ScenarioID 
		INNER JOIN dbo.ttTaskPage 
			ON dbo.ttScenarioRoleTask.TaskID = dbo.ttTaskPage.TaskID 
		INNER JOIN	CranSoft.dbo.Page 
			ON dbo.ttTaskPage.PageID = Page.PageID 	
	WHERE 
		(dbo.ttScenarioRoleTask.ActiveInScenarioRole = 1) 
		AND (Page.[Table] = N'ttMARA')  
	
	IF @boaAuditPageID IS NULL
		SELECT TOP 1 @boaAuditPageID = Page.PageID 
		FROM ttCategory 
			INNER JOIN ztParam 
				ON ztParam.WebAppID = ttCategory.DefaultWebAppID
			INNER JOIN Cransoft.dbo.Page
				ON Page.PageID = ttCategory.RequestPageId
		WHERE (Page.[Table] = N'ttMARA') AND Page.Active = 1

	IF @boaAuditPageID IS NULL
		SELECT TOP 1 @boaAuditPageID = Page2.PageID 
		FROM ttCategory 
			INNER JOIN ztParam 
				ON ztParam.WebAppID = ttCategory.DefaultWebAppID
			INNER JOIN Cransoft.dbo.Page
				ON Page.PageID = ttCategory.RequestPageId
			INNER JOIN Cransoft.dbo.PageColumn 
				ON PageColumn.PageID = Page.PageID
			INNER JOIN Cransoft.dbo.Page AS Page2
				ON Page2.PageID = PageColumn.LinkToPageID
		WHERE (Page2.[Table] = N'ttMARA') AND Page.Active = 1

	IF @boaAuditPageID IS NULL 	
		RETURN

	INSERT INTO [ttMARA#Audit]
	(
		[boaAuditProcessToken]
		,[boaAuditDateCreated]
		,[boaAuditUserID]
		,[boaAuditPageID]
		,[boaAuditEvent]
		,[RequestID],[ZCounter]
	) OUTPUT INSERTED.[boaAuditID],INSERTED.[RequestID],INSERTED.[ZCounter] 
		INTO #InsertOutput ([boaAuditID],[RequestID],[ZCounter])

	SELECT
		 NEWID() AS [boaAuditProcessToken]
		,@boaAuditDateCreated AS [boaAuditDateCreated]
		,@boaAuditUserID AS [boaAuditUserID]
		,@boaAuditPageID AS [boaAuditPageID]
		,@boaAuditEvent AS [boaAuditEvent]
		,[RequestID],[ZCounter]
	FROM    INSERTED	

	INSERT INTO [ttMARA#AuditColumn]
	(
		[boaAuditID]
		,[boaAuditChange],[RequestID],[ZCounter],[ContentRequestID],[ERSDA],[ERNAM],[LAEDA],[AENAM],[VPSTA],[PSTAT],[LVORM],[MTART],[MBRSH],[MATKL],[BISMT],[MEINS],[BSTME],[ZEINR],[ZEIAR],[ZEIVR],[ZEIFO],[AESZN],[BLATT],[BLANZ],[FERTH],[FORMT],[GROES],[WRKST],[NORMT],[LABOR],[EKWSL],[BRGEW],[NTGEW],[GEWEI],[VOLUM],[VOLEH],[BEHVO],[RAUBE],[TEMPB],[DISST],[TRAGR],[STOFF],[SPART],[KUNNR],[EANNR],[WESCH],[BWVOR],[BWSCL],[SAISO],[ETIAR],[ETIFO],[ENTAR],[EAN11],[NUMTP],[LAENG],[BREIT],[HOEHE],[MEABM],[PRDHA],[AEKLK],[CADKZ],[QMPUR],[ERGEW],[ERGEI],[ERVOL],[ERVOE],[GEWTO],[VOLTO],[VABME],[KZREV],[KZKFG],[XCHPF],[VHART],[FUELG],[STFAK],[MAGRV],[BEGRU],[DATAB],[LIQDT],[SAISJ],[PLGTP],[MLGUT],[EXTWG],[SATNR],[ATTYP],[KZKUP],[KZNFM],[PMATA],[MSTAE],[MSTAV],[MSTDE],[MSTDV],[TAKLV],[RBNRM],[MHDRZ],[MHDHB],[MHDLP],[INHME],[INHAL],[VPREH],[ETIAG],[INHBR],[CMETH],[CUOBF],[KZUMW],[KOSCH],[SPROF],[NRFHG],[MFRPN],[MFRNR],[BMATN],[MPROF],[KZWSM],[SAITY],[PROFL],[IHIVI],[ILOOS],[SERLV],[KZGVH],[XGCHP],[KZEFF],[COMPL],[IPRKZ],[RDMHD],[PRZUS],[MTPOS_MARA],[BFLME],[MATFI],[CMREL],[BBTYP],[SLED_BBD],[GTIN_VARIANT],[GENNR],[RMATP],[GDS_RELEVANT],[WEORA],[HUTYP_DFLT],[PILFERABLE],[WHSTC],[WHMATGR],[HNDLCODE],[HAZMAT],[HUTYP],[TARE_VAR],[MAXC],[MAXC_TOL],[MAXL],[MAXB],[MAXH],[MAXDIM_UOM],[HERKL],[MFRGR],[QQTIME],[QQTIMEUOM],[QGRP],[SERIAL],[PS_SMARTFORM],[LOGUNIT],[CWQREL],[CWQPROC],[CWQTOLGR],[ADPROF],[/BEV1/LULEINH],[/BEV1/LULDEGRP],[/BEV1/NESTRUCCAT],[/DSD/SL_TOLTYP],[/DSD/SV_CNT_GRP],[/DSD/VC_GROUP],[/VSO/R_TILT_IND],[/VSO/R_STACK_IND],[/VSO/R_BOT_IND],[/VSO/R_TOP_IND],[/VSO/R_STACK_NO],[/VSO/R_PAL_IND],[/VSO/R_PAL_OVR_D],[/VSO/R_PAL_OVR_W],[/VSO/R_PAL_B_HT],[/VSO/R_PAL_MIN_H],[/VSO/R_TOL_B_HT],[/VSO/R_NO_P_GVH],[/VSO/R_QUAN_UNIT],[/VSO/R_KZGVH_IND],[PACKCODE],[DG_PACK_STATUS],[MCOND],[RETDELC],[LOGLEV_RETO],[NSNID],[ADSPC_SPC],[IMATN],[PICNUM],[BSTAT],[COLOR_ATINN],[SIZE1_ATINN],[SIZE2_ATINN],[COLOR],[SIZE1],[SIZE2],[FREE_CHAR],[CARE_CODE],[BRAND_ID],[FIBER_CODE1],[FIBER_PART1],[FIBER_CODE2],[FIBER_PART2],[FIBER_CODE3],[FIBER_PART3],[FIBER_CODE4],[FIBER_PART4],[FIBER_CODE5],[FIBER_PART5],[FASHGRD],[ZZ_MAT_NUM_FOR],[ZZ_BU],[ZZ_MEDI_ELIG],[ZZ_MEDI_LOW_UNIT],[ZZ_IPP_FLAG],[ZZ_FORM],[ZZ_STRENGTH],[ZZ_REGIMEN],[ZZ_PROD_INFO],[ZZ_REORDER_LEVEL],[ZZ_REP_DRAW],[ZZ_MAX_REP_DRAW],[ZZ_INTNR],[ZZ_INTKTX],[ZZ_LIMS_FLAG],[ZZ_CRNUM],[ZZ_SPEC_DATE],[ZZ_BRAND_CD],[ZZ_PRPLANT],[ZComponentType],[ZZ_ProdVer],[ZZ_PVRecipe],[ZZ_PVOnPIR],[ZZSPGR],[MATNR],[AlreadyInSAP]
	)

	SELECT O.boaAuditID AS [boaAuditID]
		 ,1 AS [boaAuditChange],I.[RequestID],I.[ZCounter],I.[ContentRequestID],I.[ERSDA],I.[ERNAM],I.[LAEDA],I.[AENAM],I.[VPSTA],I.[PSTAT],I.[LVORM],I.[MTART],I.[MBRSH],I.[MATKL],I.[BISMT],I.[MEINS],I.[BSTME],I.[ZEINR],I.[ZEIAR],I.[ZEIVR],I.[ZEIFO],I.[AESZN],I.[BLATT],I.[BLANZ],I.[FERTH],I.[FORMT],I.[GROES],I.[WRKST],I.[NORMT],I.[LABOR],I.[EKWSL],I.[BRGEW],I.[NTGEW],I.[GEWEI],I.[VOLUM],I.[VOLEH],I.[BEHVO],I.[RAUBE],I.[TEMPB],I.[DISST],I.[TRAGR],I.[STOFF],I.[SPART],I.[KUNNR],I.[EANNR],I.[WESCH],I.[BWVOR],I.[BWSCL],I.[SAISO],I.[ETIAR],I.[ETIFO],I.[ENTAR],I.[EAN11],I.[NUMTP],I.[LAENG],I.[BREIT],I.[HOEHE],I.[MEABM],I.[PRDHA],I.[AEKLK],I.[CADKZ],I.[QMPUR],I.[ERGEW],I.[ERGEI],I.[ERVOL],I.[ERVOE],I.[GEWTO],I.[VOLTO],I.[VABME],I.[KZREV],I.[KZKFG],I.[XCHPF],I.[VHART],I.[FUELG],I.[STFAK],I.[MAGRV],I.[BEGRU],I.[DATAB],I.[LIQDT],I.[SAISJ],I.[PLGTP],I.[MLGUT],I.[EXTWG],I.[SATNR],I.[ATTYP],I.[KZKUP],I.[KZNFM],I.[PMATA],I.[MSTAE],I.[MSTAV],I.[MSTDE],I.[MSTDV],I.[TAKLV],I.[RBNRM],I.[MHDRZ],I.[MHDHB],I.[MHDLP],I.[INHME],I.[INHAL],I.[VPREH],I.[ETIAG],I.[INHBR],I.[CMETH],I.[CUOBF],I.[KZUMW],I.[KOSCH],I.[SPROF],I.[NRFHG],I.[MFRPN],I.[MFRNR],I.[BMATN],I.[MPROF],I.[KZWSM],I.[SAITY],I.[PROFL],I.[IHIVI],I.[ILOOS],I.[SERLV],I.[KZGVH],I.[XGCHP],I.[KZEFF],I.[COMPL],I.[IPRKZ],I.[RDMHD],I.[PRZUS],I.[MTPOS_MARA],I.[BFLME],I.[MATFI],I.[CMREL],I.[BBTYP],I.[SLED_BBD],I.[GTIN_VARIANT],I.[GENNR],I.[RMATP],I.[GDS_RELEVANT],I.[WEORA],I.[HUTYP_DFLT],I.[PILFERABLE],I.[WHSTC],I.[WHMATGR],I.[HNDLCODE],I.[HAZMAT],I.[HUTYP],I.[TARE_VAR],I.[MAXC],I.[MAXC_TOL],I.[MAXL],I.[MAXB],I.[MAXH],I.[MAXDIM_UOM],I.[HERKL],I.[MFRGR],I.[QQTIME],I.[QQTIMEUOM],I.[QGRP],I.[SERIAL],I.[PS_SMARTFORM],I.[LOGUNIT],I.[CWQREL],I.[CWQPROC],I.[CWQTOLGR],I.[ADPROF],I.[/BEV1/LULEINH],I.[/BEV1/LULDEGRP],I.[/BEV1/NESTRUCCAT],I.[/DSD/SL_TOLTYP],I.[/DSD/SV_CNT_GRP],I.[/DSD/VC_GROUP],I.[/VSO/R_TILT_IND],I.[/VSO/R_STACK_IND],I.[/VSO/R_BOT_IND],I.[/VSO/R_TOP_IND],I.[/VSO/R_STACK_NO],I.[/VSO/R_PAL_IND],I.[/VSO/R_PAL_OVR_D],I.[/VSO/R_PAL_OVR_W],I.[/VSO/R_PAL_B_HT],I.[/VSO/R_PAL_MIN_H],I.[/VSO/R_TOL_B_HT],I.[/VSO/R_NO_P_GVH],I.[/VSO/R_QUAN_UNIT],I.[/VSO/R_KZGVH_IND],I.[PACKCODE],I.[DG_PACK_STATUS],I.[MCOND],I.[RETDELC],I.[LOGLEV_RETO],I.[NSNID],I.[ADSPC_SPC],I.[IMATN],I.[PICNUM],I.[BSTAT],I.[COLOR_ATINN],I.[SIZE1_ATINN],I.[SIZE2_ATINN],I.[COLOR],I.[SIZE1],I.[SIZE2],I.[FREE_CHAR],I.[CARE_CODE],I.[BRAND_ID],I.[FIBER_CODE1],I.[FIBER_PART1],I.[FIBER_CODE2],I.[FIBER_PART2],I.[FIBER_CODE3],I.[FIBER_PART3],I.[FIBER_CODE4],I.[FIBER_PART4],I.[FIBER_CODE5],I.[FIBER_PART5],I.[FASHGRD],I.[ZZ_MAT_NUM_FOR],I.[ZZ_BU],I.[ZZ_MEDI_ELIG],I.[ZZ_MEDI_LOW_UNIT],I.[ZZ_IPP_FLAG],I.[ZZ_FORM],I.[ZZ_STRENGTH],I.[ZZ_REGIMEN],I.[ZZ_PROD_INFO],I.[ZZ_REORDER_LEVEL],I.[ZZ_REP_DRAW],I.[ZZ_MAX_REP_DRAW],I.[ZZ_INTNR],I.[ZZ_INTKTX],I.[ZZ_LIMS_FLAG],I.[ZZ_CRNUM],I.[ZZ_SPEC_DATE],I.[ZZ_BRAND_CD],I.[ZZ_PRPLANT],I.[ZComponentType],I.[ZZ_ProdVer],I.[ZZ_PVRecipe],I.[ZZ_PVOnPIR],I.[ZZSPGR],I.[MATNR],I.[AlreadyInSAP]
	 
	FROM INSERTED I 
	INNER JOIN #InsertOutput O 
		ON I.[RequestID] = O.[RequestID] 
		AND I.[ZCounter] = O.[ZCounter]


	DROP TABLE #InsertOutput
	END
GO

ALTER TABLE [dbo].[ttMARA] ENABLE TRIGGER [trgttMARA_AuditRecordIns]
GO

