USE [dgeMaterial_Sustain]
GO

/****** Object:  Trigger [dbo].[trgttMARA_AuditRecordUpd]    Script Date: 6/1/2022 3:56:18 PM ******/
SET ANSI_NULLS ON
GO

SET QUOTED_IDENTIFIER ON
GO

CREATE   TRIGGER [dbo].[trgttMARA_AuditRecordUpd]
   ON  [dbo].[ttMARA]
   AFTER Update
AS
BEGIN
	/* Update the audit tables when a change is made */
	DECLARE @boaAuditProcessToken NVARCHAR(50),@boaAuditDateCreated DATETIME,@boaAuditUserID NVARCHAR(150),@boaAuditEvent NVARCHAR(50),@boaAuditID INT, @ChangedVia NVARCHAR(50)
	CREATE TABLE #InsertOutput ([boaAuditID] int,[RequestID] int,[ZCounter] int)
	SET NOCOUNT ON;
	
	SELECT 
		@boaAuditDateCreated = GETDATE()
		,@boaAuditUserID = 'PageEventRule'		
		,@boaAuditEvent = 'Update'
		,@ChangedVia = [ChangedVia] FROM INSERTED
		
/* Check if update occurs in the user interface and exit trigger if true.  Set the Audit UserID to the ChangedVia field to capture stored procedure name*/
	IF (UPDATE([ChangedVia]))
		--User Interface will record updates in audit, exclude from trigger to avoid duplicates
		IF @ChangedVia = 'UserInterface'
			RETURN
		--Excel Import will record updates in audit, exclude from trigger to avoid duplicates
		IF @ChangedVia = 'ExcelImport'
			RETURN
		ELSE
			SET @boaAuditUserID = ISNULL(@ChangedVia,@boaAuditUserID)
	
	-- We should be inserting a record into this table if this table is part of the Request. Request is tied to scenario and that scenario is tied to pages. 	
	-- If you just insert in the audit table then the review role aggregate code will break  

	DECLARE @boaAuditPageID UNIQUEIDENTIFIER
	
	SELECT TOP 1 @boaAuditPageID = Page.PageID
	FROM	INSERTED AS T 
		INNER JOIN dbo.ttRequest 
			ON T.RequestID = dbo.ttRequest.RequestID 
		INNER JOIN dbo.ttScenarioRoleTask 
			ON dbo.ttRequest.ScenarioID = dbo.ttScenarioRoleTask.ScenarioID 
		INNER JOIN dbo.ttTaskPage 
			ON dbo.ttScenarioRoleTask.TaskID = dbo.ttTaskPage.TaskID 
		INNER JOIN	CranSoft.dbo.Page 
			ON dbo.ttTaskPage.PageID = Page.PageID 	
	WHERE 
		(dbo.ttScenarioRoleTask.ActiveInScenarioRole = 1) 
		AND (Page.[Table] = N'ttMARA')  
	
	IF @boaAuditPageID IS NULL
		SELECT TOP 1 @boaAuditPageID = Page.PageID 
		FROM ttCategory 
			INNER JOIN ztParam 
				ON ztParam.WebAppID = ttCategory.DefaultWebAppID
			INNER JOIN Cransoft.dbo.Page
				ON Page.PageID = ttCategory.RequestPageId
		WHERE (Page.[Table] = N'ttMARA') AND Page.Active = 1

	IF @boaAuditPageID IS NULL
		SELECT TOP 1 @boaAuditPageID = Page2.PageID 
		FROM ttCategory 
			INNER JOIN ztParam 
				ON ztParam.WebAppID = ttCategory.DefaultWebAppID
			INNER JOIN Cransoft.dbo.Page
				ON Page.PageID = ttCategory.RequestPageId
			INNER JOIN Cransoft.dbo.PageColumn 
				ON PageColumn.PageID = Page.PageID
			INNER JOIN Cransoft.dbo.Page AS Page2
				ON Page2.PageID = PageColumn.LinkToPageID
		WHERE (Page2.[Table] = N'ttMARA') AND Page.Active = 1

	IF @boaAuditPageID IS NULL 	
		RETURN

	INSERT INTO [ttMARA#Audit]
	(
		[boaAuditProcessToken]
		,[boaAuditDateCreated]
		,[boaAuditUserID]
		,[boaAuditPageID]
		,[boaAuditEvent]
		,[RequestID],[ZCounter]
	) OUTPUT INSERTED.[boaAuditID],INSERTED.[RequestID],INSERTED.[ZCounter] 
		INTO #InsertOutput ([boaAuditID],[RequestID],[ZCounter])

	SELECT
		 NEWID() AS [boaAuditProcessToken]
		,@boaAuditDateCreated AS [boaAuditDateCreated]
		,@boaAuditUserID AS [boaAuditUserID]
		,@boaAuditPageID AS [boaAuditPageID]
		,@boaAuditEvent AS [boaAuditEvent]
		,[RequestID],[ZCounter]
	FROM    INSERTED	

	INSERT INTO ttMARA#AuditColumn 
	( 
		[boaAuditID], [boaAuditChange],[ContentRequestID],[ERSDA],[ERNAM],[LAEDA],[AENAM],[VPSTA],[PSTAT],[LVORM],[MTART],[MBRSH],[MATKL],[BISMT],[MEINS],[BSTME],[ZEINR],[ZEIAR],[ZEIVR],[ZEIFO],[AESZN],[BLATT],[BLANZ],[FERTH],[FORMT],[GROES],[WRKST],[NORMT],[LABOR],[EKWSL],[BRGEW],[NTGEW],[GEWEI],[VOLUM],[VOLEH],[BEHVO],[RAUBE],[TEMPB],[DISST],[TRAGR],[STOFF],[SPART],[KUNNR],[EANNR],[WESCH],[BWVOR],[BWSCL],[SAISO],[ETIAR],[ETIFO],[ENTAR],[EAN11],[NUMTP],[LAENG],[BREIT],[HOEHE],[MEABM],[PRDHA],[AEKLK],[CADKZ],[QMPUR],[ERGEW],[ERGEI],[ERVOL],[ERVOE],[GEWTO],[VOLTO],[VABME],[KZREV],[KZKFG],[XCHPF],[VHART],[FUELG],[STFAK],[MAGRV],[BEGRU],[DATAB],[LIQDT],[SAISJ],[PLGTP],[MLGUT],[EXTWG],[SATNR],[ATTYP],[KZKUP],[KZNFM],[PMATA],[MSTAE],[MSTAV],[MSTDE],[MSTDV],[TAKLV],[RBNRM],[MHDRZ],[MHDHB],[MHDLP],[INHME],[INHAL],[VPREH],[ETIAG],[INHBR],[CMETH],[CUOBF],[KZUMW],[KOSCH],[SPROF],[NRFHG],[MFRPN],[MFRNR],[BMATN],[MPROF],[KZWSM],[SAITY],[PROFL],[IHIVI],[ILOOS],[SERLV],[KZGVH],[XGCHP],[KZEFF],[COMPL],[IPRKZ],[RDMHD],[PRZUS],[MTPOS_MARA],[BFLME],[MATFI],[CMREL],[BBTYP],[SLED_BBD],[GTIN_VARIANT],[GENNR],[RMATP],[GDS_RELEVANT],[WEORA],[HUTYP_DFLT],[PILFERABLE],[WHSTC],[WHMATGR],[HNDLCODE],[HAZMAT],[HUTYP],[TARE_VAR],[MAXC],[MAXC_TOL],[MAXL],[MAXB],[MAXH],[MAXDIM_UOM],[HERKL],[MFRGR],[QQTIME],[QQTIMEUOM],[QGRP],[SERIAL],[PS_SMARTFORM],[LOGUNIT],[CWQREL],[CWQPROC],[CWQTOLGR],[ADPROF],[/BEV1/LULEINH],[/BEV1/LULDEGRP],[/BEV1/NESTRUCCAT],[/DSD/SL_TOLTYP],[/DSD/SV_CNT_GRP],[/DSD/VC_GROUP],[/VSO/R_TILT_IND],[/VSO/R_STACK_IND],[/VSO/R_BOT_IND],[/VSO/R_TOP_IND],[/VSO/R_STACK_NO],[/VSO/R_PAL_IND],[/VSO/R_PAL_OVR_D],[/VSO/R_PAL_OVR_W],[/VSO/R_PAL_B_HT],[/VSO/R_PAL_MIN_H],[/VSO/R_TOL_B_HT],[/VSO/R_NO_P_GVH],[/VSO/R_QUAN_UNIT],[/VSO/R_KZGVH_IND],[PACKCODE],[DG_PACK_STATUS],[MCOND],[RETDELC],[LOGLEV_RETO],[NSNID],[ADSPC_SPC],[IMATN],[PICNUM],[BSTAT],[COLOR_ATINN],[SIZE1_ATINN],[SIZE2_ATINN],[COLOR],[SIZE1],[SIZE2],[FREE_CHAR],[CARE_CODE],[BRAND_ID],[FIBER_CODE1],[FIBER_PART1],[FIBER_CODE2],[FIBER_PART2],[FIBER_CODE3],[FIBER_PART3],[FIBER_CODE4],[FIBER_PART4],[FIBER_CODE5],[FIBER_PART5],[FASHGRD],[ZZ_MAT_NUM_FOR],[ZZ_BU],[ZZ_MEDI_ELIG],[ZZ_MEDI_LOW_UNIT],[ZZ_IPP_FLAG],[ZZ_FORM],[ZZ_STRENGTH],[ZZ_REGIMEN],[ZZ_PROD_INFO],[ZZ_REORDER_LEVEL],[ZZ_REP_DRAW],[ZZ_MAX_REP_DRAW],[ZZ_INTNR],[ZZ_INTKTX],[ZZ_LIMS_FLAG],[ZZ_CRNUM],[ZZ_SPEC_DATE],[ZZ_BRAND_CD],[ZZ_PRPLANT],[ZComponentType],[ZZ_ProdVer],[ZZ_PVRecipe],[ZZ_PVOnPIR],[ZZSPGR],[MATNR],[AlreadyInSAP]
	)
	SELECT O.boaAuditID, 0, NULLIF(D.[ContentRequestID], I.[ContentRequestID]),NULLIF(D.[ERSDA], I.[ERSDA]),NULLIF(D.[ERNAM], I.[ERNAM]),NULLIF(D.[LAEDA], I.[LAEDA]),NULLIF(D.[AENAM], I.[AENAM]),NULLIF(D.[VPSTA], I.[VPSTA]),NULLIF(D.[PSTAT], I.[PSTAT]),NULLIF(D.[LVORM], I.[LVORM]),NULLIF(D.[MTART], I.[MTART]),NULLIF(D.[MBRSH], I.[MBRSH]),NULLIF(D.[MATKL], I.[MATKL]),NULLIF(D.[BISMT], I.[BISMT]),NULLIF(D.[MEINS], I.[MEINS]),NULLIF(D.[BSTME], I.[BSTME]),NULLIF(D.[ZEINR], I.[ZEINR]),NULLIF(D.[ZEIAR], I.[ZEIAR]),NULLIF(D.[ZEIVR], I.[ZEIVR]),NULLIF(D.[ZEIFO], I.[ZEIFO]),NULLIF(D.[AESZN], I.[AESZN]),NULLIF(D.[BLATT], I.[BLATT]),NULLIF(D.[BLANZ], I.[BLANZ]),NULLIF(D.[FERTH], I.[FERTH]),NULLIF(D.[FORMT], I.[FORMT]),NULLIF(D.[GROES], I.[GROES]),NULLIF(D.[WRKST], I.[WRKST]),NULLIF(D.[NORMT], I.[NORMT]),NULLIF(D.[LABOR], I.[LABOR]),NULLIF(D.[EKWSL], I.[EKWSL]),NULLIF(D.[BRGEW], I.[BRGEW]),NULLIF(D.[NTGEW], I.[NTGEW]),NULLIF(D.[GEWEI], I.[GEWEI]),NULLIF(D.[VOLUM], I.[VOLUM]),NULLIF(D.[VOLEH], I.[VOLEH]),NULLIF(D.[BEHVO], I.[BEHVO]),NULLIF(D.[RAUBE], I.[RAUBE]),NULLIF(D.[TEMPB], I.[TEMPB]),NULLIF(D.[DISST], I.[DISST]),NULLIF(D.[TRAGR], I.[TRAGR]),NULLIF(D.[STOFF], I.[STOFF]),NULLIF(D.[SPART], I.[SPART]),NULLIF(D.[KUNNR], I.[KUNNR]),NULLIF(D.[EANNR], I.[EANNR]),NULLIF(D.[WESCH], I.[WESCH]),NULLIF(D.[BWVOR], I.[BWVOR]),NULLIF(D.[BWSCL], I.[BWSCL]),NULLIF(D.[SAISO], I.[SAISO]),NULLIF(D.[ETIAR], I.[ETIAR]),NULLIF(D.[ETIFO], I.[ETIFO]),NULLIF(D.[ENTAR], I.[ENTAR]),NULLIF(D.[EAN11], I.[EAN11]),NULLIF(D.[NUMTP], I.[NUMTP]),NULLIF(D.[LAENG], I.[LAENG]),NULLIF(D.[BREIT], I.[BREIT]),NULLIF(D.[HOEHE], I.[HOEHE]),NULLIF(D.[MEABM], I.[MEABM]),NULLIF(D.[PRDHA], I.[PRDHA]),NULLIF(D.[AEKLK], I.[AEKLK]),NULLIF(D.[CADKZ], I.[CADKZ]),NULLIF(D.[QMPUR], I.[QMPUR]),NULLIF(D.[ERGEW], I.[ERGEW]),NULLIF(D.[ERGEI], I.[ERGEI]),NULLIF(D.[ERVOL], I.[ERVOL]),NULLIF(D.[ERVOE], I.[ERVOE]),NULLIF(D.[GEWTO], I.[GEWTO]),NULLIF(D.[VOLTO], I.[VOLTO]),NULLIF(D.[VABME], I.[VABME]),NULLIF(D.[KZREV], I.[KZREV]),NULLIF(D.[KZKFG], I.[KZKFG]),NULLIF(D.[XCHPF], I.[XCHPF]),NULLIF(D.[VHART], I.[VHART]),NULLIF(D.[FUELG], I.[FUELG]),NULLIF(D.[STFAK], I.[STFAK]),NULLIF(D.[MAGRV], I.[MAGRV]),NULLIF(D.[BEGRU], I.[BEGRU]),NULLIF(D.[DATAB], I.[DATAB]),NULLIF(D.[LIQDT], I.[LIQDT]),NULLIF(D.[SAISJ], I.[SAISJ]),NULLIF(D.[PLGTP], I.[PLGTP]),NULLIF(D.[MLGUT], I.[MLGUT]),NULLIF(D.[EXTWG], I.[EXTWG]),NULLIF(D.[SATNR], I.[SATNR]),NULLIF(D.[ATTYP], I.[ATTYP]),NULLIF(D.[KZKUP], I.[KZKUP]),NULLIF(D.[KZNFM], I.[KZNFM]),NULLIF(D.[PMATA], I.[PMATA]),NULLIF(D.[MSTAE], I.[MSTAE]),NULLIF(D.[MSTAV], I.[MSTAV]),NULLIF(D.[MSTDE], I.[MSTDE]),NULLIF(D.[MSTDV], I.[MSTDV]),NULLIF(D.[TAKLV], I.[TAKLV]),NULLIF(D.[RBNRM], I.[RBNRM]),NULLIF(D.[MHDRZ], I.[MHDRZ]),NULLIF(D.[MHDHB], I.[MHDHB]),NULLIF(D.[MHDLP], I.[MHDLP]),NULLIF(D.[INHME], I.[INHME]),NULLIF(D.[INHAL], I.[INHAL]),NULLIF(D.[VPREH], I.[VPREH]),NULLIF(D.[ETIAG], I.[ETIAG]),NULLIF(D.[INHBR], I.[INHBR]),NULLIF(D.[CMETH], I.[CMETH]),NULLIF(D.[CUOBF], I.[CUOBF]),NULLIF(D.[KZUMW], I.[KZUMW]),NULLIF(D.[KOSCH], I.[KOSCH]),NULLIF(D.[SPROF], I.[SPROF]),NULLIF(D.[NRFHG], I.[NRFHG]),NULLIF(D.[MFRPN], I.[MFRPN]),NULLIF(D.[MFRNR], I.[MFRNR]),NULLIF(D.[BMATN], I.[BMATN]),NULLIF(D.[MPROF], I.[MPROF]),NULLIF(D.[KZWSM], I.[KZWSM]),NULLIF(D.[SAITY], I.[SAITY]),NULLIF(D.[PROFL], I.[PROFL]),NULLIF(D.[IHIVI], I.[IHIVI]),NULLIF(D.[ILOOS], I.[ILOOS]),NULLIF(D.[SERLV], I.[SERLV]),NULLIF(D.[KZGVH], I.[KZGVH]),NULLIF(D.[XGCHP], I.[XGCHP]),NULLIF(D.[KZEFF], I.[KZEFF]),NULLIF(D.[COMPL], I.[COMPL]),NULLIF(D.[IPRKZ], I.[IPRKZ]),NULLIF(D.[RDMHD], I.[RDMHD]),NULLIF(D.[PRZUS], I.[PRZUS]),NULLIF(D.[MTPOS_MARA], I.[MTPOS_MARA]),NULLIF(D.[BFLME], I.[BFLME]),NULLIF(D.[MATFI], I.[MATFI]),NULLIF(D.[CMREL], I.[CMREL]),NULLIF(D.[BBTYP], I.[BBTYP]),NULLIF(D.[SLED_BBD], I.[SLED_BBD]),NULLIF(D.[GTIN_VARIANT], I.[GTIN_VARIANT]),NULLIF(D.[GENNR], I.[GENNR]),NULLIF(D.[RMATP], I.[RMATP]),NULLIF(D.[GDS_RELEVANT], I.[GDS_RELEVANT]),NULLIF(D.[WEORA], I.[WEORA]),NULLIF(D.[HUTYP_DFLT], I.[HUTYP_DFLT]),NULLIF(D.[PILFERABLE], I.[PILFERABLE]),NULLIF(D.[WHSTC], I.[WHSTC]),NULLIF(D.[WHMATGR], I.[WHMATGR]),NULLIF(D.[HNDLCODE], I.[HNDLCODE]),NULLIF(D.[HAZMAT], I.[HAZMAT]),NULLIF(D.[HUTYP], I.[HUTYP]),NULLIF(D.[TARE_VAR], I.[TARE_VAR]),NULLIF(D.[MAXC], I.[MAXC]),NULLIF(D.[MAXC_TOL], I.[MAXC_TOL]),NULLIF(D.[MAXL], I.[MAXL]),NULLIF(D.[MAXB], I.[MAXB]),NULLIF(D.[MAXH], I.[MAXH]),NULLIF(D.[MAXDIM_UOM], I.[MAXDIM_UOM]),NULLIF(D.[HERKL], I.[HERKL]),NULLIF(D.[MFRGR], I.[MFRGR]),NULLIF(D.[QQTIME], I.[QQTIME]),NULLIF(D.[QQTIMEUOM], I.[QQTIMEUOM]),NULLIF(D.[QGRP], I.[QGRP]),NULLIF(D.[SERIAL], I.[SERIAL]),NULLIF(D.[PS_SMARTFORM], I.[PS_SMARTFORM]),NULLIF(D.[LOGUNIT], I.[LOGUNIT]),NULLIF(D.[CWQREL], I.[CWQREL]),NULLIF(D.[CWQPROC], I.[CWQPROC]),NULLIF(D.[CWQTOLGR], I.[CWQTOLGR]),NULLIF(D.[ADPROF], I.[ADPROF]),NULLIF(D.[/BEV1/LULEINH], I.[/BEV1/LULEINH]),NULLIF(D.[/BEV1/LULDEGRP], I.[/BEV1/LULDEGRP]),NULLIF(D.[/BEV1/NESTRUCCAT], I.[/BEV1/NESTRUCCAT]),NULLIF(D.[/DSD/SL_TOLTYP], I.[/DSD/SL_TOLTYP]),NULLIF(D.[/DSD/SV_CNT_GRP], I.[/DSD/SV_CNT_GRP]),NULLIF(D.[/DSD/VC_GROUP], I.[/DSD/VC_GROUP]),NULLIF(D.[/VSO/R_TILT_IND], I.[/VSO/R_TILT_IND]),NULLIF(D.[/VSO/R_STACK_IND], I.[/VSO/R_STACK_IND]),NULLIF(D.[/VSO/R_BOT_IND], I.[/VSO/R_BOT_IND]),NULLIF(D.[/VSO/R_TOP_IND], I.[/VSO/R_TOP_IND]),NULLIF(D.[/VSO/R_STACK_NO], I.[/VSO/R_STACK_NO]),NULLIF(D.[/VSO/R_PAL_IND], I.[/VSO/R_PAL_IND]),NULLIF(D.[/VSO/R_PAL_OVR_D], I.[/VSO/R_PAL_OVR_D]),NULLIF(D.[/VSO/R_PAL_OVR_W], I.[/VSO/R_PAL_OVR_W]),NULLIF(D.[/VSO/R_PAL_B_HT], I.[/VSO/R_PAL_B_HT]),NULLIF(D.[/VSO/R_PAL_MIN_H], I.[/VSO/R_PAL_MIN_H]),NULLIF(D.[/VSO/R_TOL_B_HT], I.[/VSO/R_TOL_B_HT]),NULLIF(D.[/VSO/R_NO_P_GVH], I.[/VSO/R_NO_P_GVH]),NULLIF(D.[/VSO/R_QUAN_UNIT], I.[/VSO/R_QUAN_UNIT]),NULLIF(D.[/VSO/R_KZGVH_IND], I.[/VSO/R_KZGVH_IND]),NULLIF(D.[PACKCODE], I.[PACKCODE]),NULLIF(D.[DG_PACK_STATUS], I.[DG_PACK_STATUS]),NULLIF(D.[MCOND], I.[MCOND]),NULLIF(D.[RETDELC], I.[RETDELC]),NULLIF(D.[LOGLEV_RETO], I.[LOGLEV_RETO]),NULLIF(D.[NSNID], I.[NSNID]),NULLIF(D.[ADSPC_SPC], I.[ADSPC_SPC]),NULLIF(D.[IMATN], I.[IMATN]),NULLIF(D.[PICNUM], I.[PICNUM]),NULLIF(D.[BSTAT], I.[BSTAT]),NULLIF(D.[COLOR_ATINN], I.[COLOR_ATINN]),NULLIF(D.[SIZE1_ATINN], I.[SIZE1_ATINN]),NULLIF(D.[SIZE2_ATINN], I.[SIZE2_ATINN]),NULLIF(D.[COLOR], I.[COLOR]),NULLIF(D.[SIZE1], I.[SIZE1]),NULLIF(D.[SIZE2], I.[SIZE2]),NULLIF(D.[FREE_CHAR], I.[FREE_CHAR]),NULLIF(D.[CARE_CODE], I.[CARE_CODE]),NULLIF(D.[BRAND_ID], I.[BRAND_ID]),NULLIF(D.[FIBER_CODE1], I.[FIBER_CODE1]),NULLIF(D.[FIBER_PART1], I.[FIBER_PART1]),NULLIF(D.[FIBER_CODE2], I.[FIBER_CODE2]),NULLIF(D.[FIBER_PART2], I.[FIBER_PART2]),NULLIF(D.[FIBER_CODE3], I.[FIBER_CODE3]),NULLIF(D.[FIBER_PART3], I.[FIBER_PART3]),NULLIF(D.[FIBER_CODE4], I.[FIBER_CODE4]),NULLIF(D.[FIBER_PART4], I.[FIBER_PART4]),NULLIF(D.[FIBER_CODE5], I.[FIBER_CODE5]),NULLIF(D.[FIBER_PART5], I.[FIBER_PART5]),NULLIF(D.[FASHGRD], I.[FASHGRD]),NULLIF(D.[ZZ_MAT_NUM_FOR], I.[ZZ_MAT_NUM_FOR]),NULLIF(D.[ZZ_BU], I.[ZZ_BU]),NULLIF(D.[ZZ_MEDI_ELIG], I.[ZZ_MEDI_ELIG]),NULLIF(D.[ZZ_MEDI_LOW_UNIT], I.[ZZ_MEDI_LOW_UNIT]),NULLIF(D.[ZZ_IPP_FLAG], I.[ZZ_IPP_FLAG]),NULLIF(D.[ZZ_FORM], I.[ZZ_FORM]),NULLIF(D.[ZZ_STRENGTH], I.[ZZ_STRENGTH]),NULLIF(D.[ZZ_REGIMEN], I.[ZZ_REGIMEN]),NULLIF(D.[ZZ_PROD_INFO], I.[ZZ_PROD_INFO]),NULLIF(D.[ZZ_REORDER_LEVEL], I.[ZZ_REORDER_LEVEL]),NULLIF(D.[ZZ_REP_DRAW], I.[ZZ_REP_DRAW]),NULLIF(D.[ZZ_MAX_REP_DRAW], I.[ZZ_MAX_REP_DRAW]),NULLIF(D.[ZZ_INTNR], I.[ZZ_INTNR]),NULLIF(D.[ZZ_INTKTX], I.[ZZ_INTKTX]),NULLIF(D.[ZZ_LIMS_FLAG], I.[ZZ_LIMS_FLAG]),NULLIF(D.[ZZ_CRNUM], I.[ZZ_CRNUM]),NULLIF(D.[ZZ_SPEC_DATE], I.[ZZ_SPEC_DATE]),NULLIF(D.[ZZ_BRAND_CD], I.[ZZ_BRAND_CD]),NULLIF(D.[ZZ_PRPLANT], I.[ZZ_PRPLANT]),NULLIF(D.[ZComponentType], I.[ZComponentType]),NULLIF(D.[ZZ_ProdVer], I.[ZZ_ProdVer]),NULLIF(D.[ZZ_PVRecipe], I.[ZZ_PVRecipe]),NULLIF(D.[ZZ_PVOnPIR], I.[ZZ_PVOnPIR]),NULLIF(D.[ZZSPGR], I.[ZZSPGR]),NULLIF(D.[MATNR], I.[MATNR]),NULLIF(D.[AlreadyInSAP], I.[AlreadyInSAP]) 
	FROM INSERTED I 
	INNER JOIN DELETED D 
		ON I.[RequestID] = D.[RequestID] 
		AND I.[ZCounter] = D.[ZCounter]
	INNER JOIN #InsertOutput O
		ON I.[RequestID] = O.[RequestID] 
		AND I.[ZCounter] = O.[ZCounter]
	
	INSERT INTO ttMARA#AuditColumn 
	( 
		[boaAuditID], [boaAuditChange],[ContentRequestID],[ERSDA],[ERNAM],[LAEDA],[AENAM],[VPSTA],[PSTAT],[LVORM],[MTART],[MBRSH],[MATKL],[BISMT],[MEINS],[BSTME],[ZEINR],[ZEIAR],[ZEIVR],[ZEIFO],[AESZN],[BLATT],[BLANZ],[FERTH],[FORMT],[GROES],[WRKST],[NORMT],[LABOR],[EKWSL],[BRGEW],[NTGEW],[GEWEI],[VOLUM],[VOLEH],[BEHVO],[RAUBE],[TEMPB],[DISST],[TRAGR],[STOFF],[SPART],[KUNNR],[EANNR],[WESCH],[BWVOR],[BWSCL],[SAISO],[ETIAR],[ETIFO],[ENTAR],[EAN11],[NUMTP],[LAENG],[BREIT],[HOEHE],[MEABM],[PRDHA],[AEKLK],[CADKZ],[QMPUR],[ERGEW],[ERGEI],[ERVOL],[ERVOE],[GEWTO],[VOLTO],[VABME],[KZREV],[KZKFG],[XCHPF],[VHART],[FUELG],[STFAK],[MAGRV],[BEGRU],[DATAB],[LIQDT],[SAISJ],[PLGTP],[MLGUT],[EXTWG],[SATNR],[ATTYP],[KZKUP],[KZNFM],[PMATA],[MSTAE],[MSTAV],[MSTDE],[MSTDV],[TAKLV],[RBNRM],[MHDRZ],[MHDHB],[MHDLP],[INHME],[INHAL],[VPREH],[ETIAG],[INHBR],[CMETH],[CUOBF],[KZUMW],[KOSCH],[SPROF],[NRFHG],[MFRPN],[MFRNR],[BMATN],[MPROF],[KZWSM],[SAITY],[PROFL],[IHIVI],[ILOOS],[SERLV],[KZGVH],[XGCHP],[KZEFF],[COMPL],[IPRKZ],[RDMHD],[PRZUS],[MTPOS_MARA],[BFLME],[MATFI],[CMREL],[BBTYP],[SLED_BBD],[GTIN_VARIANT],[GENNR],[RMATP],[GDS_RELEVANT],[WEORA],[HUTYP_DFLT],[PILFERABLE],[WHSTC],[WHMATGR],[HNDLCODE],[HAZMAT],[HUTYP],[TARE_VAR],[MAXC],[MAXC_TOL],[MAXL],[MAXB],[MAXH],[MAXDIM_UOM],[HERKL],[MFRGR],[QQTIME],[QQTIMEUOM],[QGRP],[SERIAL],[PS_SMARTFORM],[LOGUNIT],[CWQREL],[CWQPROC],[CWQTOLGR],[ADPROF],[/BEV1/LULEINH],[/BEV1/LULDEGRP],[/BEV1/NESTRUCCAT],[/DSD/SL_TOLTYP],[/DSD/SV_CNT_GRP],[/DSD/VC_GROUP],[/VSO/R_TILT_IND],[/VSO/R_STACK_IND],[/VSO/R_BOT_IND],[/VSO/R_TOP_IND],[/VSO/R_STACK_NO],[/VSO/R_PAL_IND],[/VSO/R_PAL_OVR_D],[/VSO/R_PAL_OVR_W],[/VSO/R_PAL_B_HT],[/VSO/R_PAL_MIN_H],[/VSO/R_TOL_B_HT],[/VSO/R_NO_P_GVH],[/VSO/R_QUAN_UNIT],[/VSO/R_KZGVH_IND],[PACKCODE],[DG_PACK_STATUS],[MCOND],[RETDELC],[LOGLEV_RETO],[NSNID],[ADSPC_SPC],[IMATN],[PICNUM],[BSTAT],[COLOR_ATINN],[SIZE1_ATINN],[SIZE2_ATINN],[COLOR],[SIZE1],[SIZE2],[FREE_CHAR],[CARE_CODE],[BRAND_ID],[FIBER_CODE1],[FIBER_PART1],[FIBER_CODE2],[FIBER_PART2],[FIBER_CODE3],[FIBER_PART3],[FIBER_CODE4],[FIBER_PART4],[FIBER_CODE5],[FIBER_PART5],[FASHGRD],[ZZ_MAT_NUM_FOR],[ZZ_BU],[ZZ_MEDI_ELIG],[ZZ_MEDI_LOW_UNIT],[ZZ_IPP_FLAG],[ZZ_FORM],[ZZ_STRENGTH],[ZZ_REGIMEN],[ZZ_PROD_INFO],[ZZ_REORDER_LEVEL],[ZZ_REP_DRAW],[ZZ_MAX_REP_DRAW],[ZZ_INTNR],[ZZ_INTKTX],[ZZ_LIMS_FLAG],[ZZ_CRNUM],[ZZ_SPEC_DATE],[ZZ_BRAND_CD],[ZZ_PRPLANT],[ZComponentType],[ZZ_ProdVer],[ZZ_PVRecipe],[ZZ_PVOnPIR],[ZZSPGR],[MATNR],[AlreadyInSAP]
	)
	SELECT O.boaAuditID, 1, NULLIF(I.[ContentRequestID], D.[ContentRequestID]),NULLIF(I.[ERSDA], D.[ERSDA]),NULLIF(I.[ERNAM], D.[ERNAM]),NULLIF(I.[LAEDA], D.[LAEDA]),NULLIF(I.[AENAM], D.[AENAM]),NULLIF(I.[VPSTA], D.[VPSTA]),NULLIF(I.[PSTAT], D.[PSTAT]),NULLIF(I.[LVORM], D.[LVORM]),NULLIF(I.[MTART], D.[MTART]),NULLIF(I.[MBRSH], D.[MBRSH]),NULLIF(I.[MATKL], D.[MATKL]),NULLIF(I.[BISMT], D.[BISMT]),NULLIF(I.[MEINS], D.[MEINS]),NULLIF(I.[BSTME], D.[BSTME]),NULLIF(I.[ZEINR], D.[ZEINR]),NULLIF(I.[ZEIAR], D.[ZEIAR]),NULLIF(I.[ZEIVR], D.[ZEIVR]),NULLIF(I.[ZEIFO], D.[ZEIFO]),NULLIF(I.[AESZN], D.[AESZN]),NULLIF(I.[BLATT], D.[BLATT]),NULLIF(I.[BLANZ], D.[BLANZ]),NULLIF(I.[FERTH], D.[FERTH]),NULLIF(I.[FORMT], D.[FORMT]),NULLIF(I.[GROES], D.[GROES]),NULLIF(I.[WRKST], D.[WRKST]),NULLIF(I.[NORMT], D.[NORMT]),NULLIF(I.[LABOR], D.[LABOR]),NULLIF(I.[EKWSL], D.[EKWSL]),NULLIF(I.[BRGEW], D.[BRGEW]),NULLIF(I.[NTGEW], D.[NTGEW]),NULLIF(I.[GEWEI], D.[GEWEI]),NULLIF(I.[VOLUM], D.[VOLUM]),NULLIF(I.[VOLEH], D.[VOLEH]),NULLIF(I.[BEHVO], D.[BEHVO]),NULLIF(I.[RAUBE], D.[RAUBE]),NULLIF(I.[TEMPB], D.[TEMPB]),NULLIF(I.[DISST], D.[DISST]),NULLIF(I.[TRAGR], D.[TRAGR]),NULLIF(I.[STOFF], D.[STOFF]),NULLIF(I.[SPART], D.[SPART]),NULLIF(I.[KUNNR], D.[KUNNR]),NULLIF(I.[EANNR], D.[EANNR]),NULLIF(I.[WESCH], D.[WESCH]),NULLIF(I.[BWVOR], D.[BWVOR]),NULLIF(I.[BWSCL], D.[BWSCL]),NULLIF(I.[SAISO], D.[SAISO]),NULLIF(I.[ETIAR], D.[ETIAR]),NULLIF(I.[ETIFO], D.[ETIFO]),NULLIF(I.[ENTAR], D.[ENTAR]),NULLIF(I.[EAN11], D.[EAN11]),NULLIF(I.[NUMTP], D.[NUMTP]),NULLIF(I.[LAENG], D.[LAENG]),NULLIF(I.[BREIT], D.[BREIT]),NULLIF(I.[HOEHE], D.[HOEHE]),NULLIF(I.[MEABM], D.[MEABM]),NULLIF(I.[PRDHA], D.[PRDHA]),NULLIF(I.[AEKLK], D.[AEKLK]),NULLIF(I.[CADKZ], D.[CADKZ]),NULLIF(I.[QMPUR], D.[QMPUR]),NULLIF(I.[ERGEW], D.[ERGEW]),NULLIF(I.[ERGEI], D.[ERGEI]),NULLIF(I.[ERVOL], D.[ERVOL]),NULLIF(I.[ERVOE], D.[ERVOE]),NULLIF(I.[GEWTO], D.[GEWTO]),NULLIF(I.[VOLTO], D.[VOLTO]),NULLIF(I.[VABME], D.[VABME]),NULLIF(I.[KZREV], D.[KZREV]),NULLIF(I.[KZKFG], D.[KZKFG]),NULLIF(I.[XCHPF], D.[XCHPF]),NULLIF(I.[VHART], D.[VHART]),NULLIF(I.[FUELG], D.[FUELG]),NULLIF(I.[STFAK], D.[STFAK]),NULLIF(I.[MAGRV], D.[MAGRV]),NULLIF(I.[BEGRU], D.[BEGRU]),NULLIF(I.[DATAB], D.[DATAB]),NULLIF(I.[LIQDT], D.[LIQDT]),NULLIF(I.[SAISJ], D.[SAISJ]),NULLIF(I.[PLGTP], D.[PLGTP]),NULLIF(I.[MLGUT], D.[MLGUT]),NULLIF(I.[EXTWG], D.[EXTWG]),NULLIF(I.[SATNR], D.[SATNR]),NULLIF(I.[ATTYP], D.[ATTYP]),NULLIF(I.[KZKUP], D.[KZKUP]),NULLIF(I.[KZNFM], D.[KZNFM]),NULLIF(I.[PMATA], D.[PMATA]),NULLIF(I.[MSTAE], D.[MSTAE]),NULLIF(I.[MSTAV], D.[MSTAV]),NULLIF(I.[MSTDE], D.[MSTDE]),NULLIF(I.[MSTDV], D.[MSTDV]),NULLIF(I.[TAKLV], D.[TAKLV]),NULLIF(I.[RBNRM], D.[RBNRM]),NULLIF(I.[MHDRZ], D.[MHDRZ]),NULLIF(I.[MHDHB], D.[MHDHB]),NULLIF(I.[MHDLP], D.[MHDLP]),NULLIF(I.[INHME], D.[INHME]),NULLIF(I.[INHAL], D.[INHAL]),NULLIF(I.[VPREH], D.[VPREH]),NULLIF(I.[ETIAG], D.[ETIAG]),NULLIF(I.[INHBR], D.[INHBR]),NULLIF(I.[CMETH], D.[CMETH]),NULLIF(I.[CUOBF], D.[CUOBF]),NULLIF(I.[KZUMW], D.[KZUMW]),NULLIF(I.[KOSCH], D.[KOSCH]),NULLIF(I.[SPROF], D.[SPROF]),NULLIF(I.[NRFHG], D.[NRFHG]),NULLIF(I.[MFRPN], D.[MFRPN]),NULLIF(I.[MFRNR], D.[MFRNR]),NULLIF(I.[BMATN], D.[BMATN]),NULLIF(I.[MPROF], D.[MPROF]),NULLIF(I.[KZWSM], D.[KZWSM]),NULLIF(I.[SAITY], D.[SAITY]),NULLIF(I.[PROFL], D.[PROFL]),NULLIF(I.[IHIVI], D.[IHIVI]),NULLIF(I.[ILOOS], D.[ILOOS]),NULLIF(I.[SERLV], D.[SERLV]),NULLIF(I.[KZGVH], D.[KZGVH]),NULLIF(I.[XGCHP], D.[XGCHP]),NULLIF(I.[KZEFF], D.[KZEFF]),NULLIF(I.[COMPL], D.[COMPL]),NULLIF(I.[IPRKZ], D.[IPRKZ]),NULLIF(I.[RDMHD], D.[RDMHD]),NULLIF(I.[PRZUS], D.[PRZUS]),NULLIF(I.[MTPOS_MARA], D.[MTPOS_MARA]),NULLIF(I.[BFLME], D.[BFLME]),NULLIF(I.[MATFI], D.[MATFI]),NULLIF(I.[CMREL], D.[CMREL]),NULLIF(I.[BBTYP], D.[BBTYP]),NULLIF(I.[SLED_BBD], D.[SLED_BBD]),NULLIF(I.[GTIN_VARIANT], D.[GTIN_VARIANT]),NULLIF(I.[GENNR], D.[GENNR]),NULLIF(I.[RMATP], D.[RMATP]),NULLIF(I.[GDS_RELEVANT], D.[GDS_RELEVANT]),NULLIF(I.[WEORA], D.[WEORA]),NULLIF(I.[HUTYP_DFLT], D.[HUTYP_DFLT]),NULLIF(I.[PILFERABLE], D.[PILFERABLE]),NULLIF(I.[WHSTC], D.[WHSTC]),NULLIF(I.[WHMATGR], D.[WHMATGR]),NULLIF(I.[HNDLCODE], D.[HNDLCODE]),NULLIF(I.[HAZMAT], D.[HAZMAT]),NULLIF(I.[HUTYP], D.[HUTYP]),NULLIF(I.[TARE_VAR], D.[TARE_VAR]),NULLIF(I.[MAXC], D.[MAXC]),NULLIF(I.[MAXC_TOL], D.[MAXC_TOL]),NULLIF(I.[MAXL], D.[MAXL]),NULLIF(I.[MAXB], D.[MAXB]),NULLIF(I.[MAXH], D.[MAXH]),NULLIF(I.[MAXDIM_UOM], D.[MAXDIM_UOM]),NULLIF(I.[HERKL], D.[HERKL]),NULLIF(I.[MFRGR], D.[MFRGR]),NULLIF(I.[QQTIME], D.[QQTIME]),NULLIF(I.[QQTIMEUOM], D.[QQTIMEUOM]),NULLIF(I.[QGRP], D.[QGRP]),NULLIF(I.[SERIAL], D.[SERIAL]),NULLIF(I.[PS_SMARTFORM], D.[PS_SMARTFORM]),NULLIF(I.[LOGUNIT], D.[LOGUNIT]),NULLIF(I.[CWQREL], D.[CWQREL]),NULLIF(I.[CWQPROC], D.[CWQPROC]),NULLIF(I.[CWQTOLGR], D.[CWQTOLGR]),NULLIF(I.[ADPROF], D.[ADPROF]),NULLIF(I.[/BEV1/LULEINH], D.[/BEV1/LULEINH]),NULLIF(I.[/BEV1/LULDEGRP], D.[/BEV1/LULDEGRP]),NULLIF(I.[/BEV1/NESTRUCCAT], D.[/BEV1/NESTRUCCAT]),NULLIF(I.[/DSD/SL_TOLTYP], D.[/DSD/SL_TOLTYP]),NULLIF(I.[/DSD/SV_CNT_GRP], D.[/DSD/SV_CNT_GRP]),NULLIF(I.[/DSD/VC_GROUP], D.[/DSD/VC_GROUP]),NULLIF(I.[/VSO/R_TILT_IND], D.[/VSO/R_TILT_IND]),NULLIF(I.[/VSO/R_STACK_IND], D.[/VSO/R_STACK_IND]),NULLIF(I.[/VSO/R_BOT_IND], D.[/VSO/R_BOT_IND]),NULLIF(I.[/VSO/R_TOP_IND], D.[/VSO/R_TOP_IND]),NULLIF(I.[/VSO/R_STACK_NO], D.[/VSO/R_STACK_NO]),NULLIF(I.[/VSO/R_PAL_IND], D.[/VSO/R_PAL_IND]),NULLIF(I.[/VSO/R_PAL_OVR_D], D.[/VSO/R_PAL_OVR_D]),NULLIF(I.[/VSO/R_PAL_OVR_W], D.[/VSO/R_PAL_OVR_W]),NULLIF(I.[/VSO/R_PAL_B_HT], D.[/VSO/R_PAL_B_HT]),NULLIF(I.[/VSO/R_PAL_MIN_H], D.[/VSO/R_PAL_MIN_H]),NULLIF(I.[/VSO/R_TOL_B_HT], D.[/VSO/R_TOL_B_HT]),NULLIF(I.[/VSO/R_NO_P_GVH], D.[/VSO/R_NO_P_GVH]),NULLIF(I.[/VSO/R_QUAN_UNIT], D.[/VSO/R_QUAN_UNIT]),NULLIF(I.[/VSO/R_KZGVH_IND], D.[/VSO/R_KZGVH_IND]),NULLIF(I.[PACKCODE], D.[PACKCODE]),NULLIF(I.[DG_PACK_STATUS], D.[DG_PACK_STATUS]),NULLIF(I.[MCOND], D.[MCOND]),NULLIF(I.[RETDELC], D.[RETDELC]),NULLIF(I.[LOGLEV_RETO], D.[LOGLEV_RETO]),NULLIF(I.[NSNID], D.[NSNID]),NULLIF(I.[ADSPC_SPC], D.[ADSPC_SPC]),NULLIF(I.[IMATN], D.[IMATN]),NULLIF(I.[PICNUM], D.[PICNUM]),NULLIF(I.[BSTAT], D.[BSTAT]),NULLIF(I.[COLOR_ATINN], D.[COLOR_ATINN]),NULLIF(I.[SIZE1_ATINN], D.[SIZE1_ATINN]),NULLIF(I.[SIZE2_ATINN], D.[SIZE2_ATINN]),NULLIF(I.[COLOR], D.[COLOR]),NULLIF(I.[SIZE1], D.[SIZE1]),NULLIF(I.[SIZE2], D.[SIZE2]),NULLIF(I.[FREE_CHAR], D.[FREE_CHAR]),NULLIF(I.[CARE_CODE], D.[CARE_CODE]),NULLIF(I.[BRAND_ID], D.[BRAND_ID]),NULLIF(I.[FIBER_CODE1], D.[FIBER_CODE1]),NULLIF(I.[FIBER_PART1], D.[FIBER_PART1]),NULLIF(I.[FIBER_CODE2], D.[FIBER_CODE2]),NULLIF(I.[FIBER_PART2], D.[FIBER_PART2]),NULLIF(I.[FIBER_CODE3], D.[FIBER_CODE3]),NULLIF(I.[FIBER_PART3], D.[FIBER_PART3]),NULLIF(I.[FIBER_CODE4], D.[FIBER_CODE4]),NULLIF(I.[FIBER_PART4], D.[FIBER_PART4]),NULLIF(I.[FIBER_CODE5], D.[FIBER_CODE5]),NULLIF(I.[FIBER_PART5], D.[FIBER_PART5]),NULLIF(I.[FASHGRD], D.[FASHGRD]),NULLIF(I.[ZZ_MAT_NUM_FOR], D.[ZZ_MAT_NUM_FOR]),NULLIF(I.[ZZ_BU], D.[ZZ_BU]),NULLIF(I.[ZZ_MEDI_ELIG], D.[ZZ_MEDI_ELIG]),NULLIF(I.[ZZ_MEDI_LOW_UNIT], D.[ZZ_MEDI_LOW_UNIT]),NULLIF(I.[ZZ_IPP_FLAG], D.[ZZ_IPP_FLAG]),NULLIF(I.[ZZ_FORM], D.[ZZ_FORM]),NULLIF(I.[ZZ_STRENGTH], D.[ZZ_STRENGTH]),NULLIF(I.[ZZ_REGIMEN], D.[ZZ_REGIMEN]),NULLIF(I.[ZZ_PROD_INFO], D.[ZZ_PROD_INFO]),NULLIF(I.[ZZ_REORDER_LEVEL], D.[ZZ_REORDER_LEVEL]),NULLIF(I.[ZZ_REP_DRAW], D.[ZZ_REP_DRAW]),NULLIF(I.[ZZ_MAX_REP_DRAW], D.[ZZ_MAX_REP_DRAW]),NULLIF(I.[ZZ_INTNR], D.[ZZ_INTNR]),NULLIF(I.[ZZ_INTKTX], D.[ZZ_INTKTX]),NULLIF(I.[ZZ_LIMS_FLAG], D.[ZZ_LIMS_FLAG]),NULLIF(I.[ZZ_CRNUM], D.[ZZ_CRNUM]),NULLIF(I.[ZZ_SPEC_DATE], D.[ZZ_SPEC_DATE]),NULLIF(I.[ZZ_BRAND_CD], D.[ZZ_BRAND_CD]),NULLIF(I.[ZZ_PRPLANT], D.[ZZ_PRPLANT]),NULLIF(I.[ZComponentType], D.[ZComponentType]),NULLIF(I.[ZZ_ProdVer], D.[ZZ_ProdVer]),NULLIF(I.[ZZ_PVRecipe], D.[ZZ_PVRecipe]),NULLIF(I.[ZZ_PVOnPIR], D.[ZZ_PVOnPIR]),NULLIF(I.[ZZSPGR], D.[ZZSPGR]),NULLIF(I.[MATNR], D.[MATNR]),NULLIF(I.[AlreadyInSAP], D.[AlreadyInSAP]) 
	FROM INSERTED I 
	INNER JOIN DELETED D 
		ON I.[RequestID] = D.[RequestID] 
		AND I.[ZCounter] = D.[ZCounter]
	INNER JOIN #InsertOutput O
		ON I.[RequestID] = O.[RequestID] 
		AND I.[ZCounter] = O.[ZCounter]


	DROP TABLE #InsertOutput
	END
GO

ALTER TABLE [dbo].[ttMARA] ENABLE TRIGGER [trgttMARA_AuditRecordUpd]
GO

