USE [MC]
GO

/****** Object:  StoredProcedure [dbo].[CreateTriggerForAuditTable]    Script Date: 5/27/2022 2:38:05 PM ******/
SET ANSI_NULLS ON
GO

SET QUOTED_IDENTIFIER ON
GO

CREATE PROCEDURE [dbo].[CreateTriggerForAuditTable]
(
	 @Database					SYSNAME	
	,@TriggerType				NVARCHAR(50)
	,@TriggerTable				NVARCHAR(150)
	,@TriggerAuditTable			NVARCHAR(250) = NULL 
	,@TriggerAuditColumnTable	NVARCHAR(250) = NULL
	,@DropTriggersOnly			INT = 0
)
AS
DECLARE @TriggerDefinition NVARCHAR(MAX),@DropTriggerSQL NVARCHAR(300),@PKeys NVARCHAR(MAX), @PKeysType NVARCHAR(MAX), @PKeysInserted NVARCHAR(MAX), @ColumnListIns NVARCHAR(MAX),@ColumnListSel NVARCHAR(MAX),@UpdateTrigger NVARCHAR(MAX),@InsertTrigger NVARCHAR(MAX),@DeleteTrigger NVARCHAR(MAX),@TriggerName NVARCHAR(250)
DECLARE @Query NVARCHAR(MAX), @UpdColumnListDel NVARCHAR(MAX),@UpdFrom NVARCHAR(MAX), @UpdInsertTo NVARCHAR(MAX), @UpdColumnListIns NVARCHAR(MAX), @InsFrom NVARCHAR(MAX), @DelFrom NVARCHAR(MAX)

SELECT @TriggerName = 'trg'+@TriggerTable+'_AuditRecord'+LEFT(@TriggerType,3)
	, @DropTriggerSQL = 'DROP TRIGGER '+@TriggerName

--Drop Triggers and exit proc if parameter inicates
IF @DropTriggersOnly = 1
BEGIN
	IF OBJECT_ID(@database+'.dbo.'+@TriggerName) IS NOT NULL
	BEGIN
		EXEC dspCommon.dbo.webExecuteSQL @DropTriggerSQL,@Database
		RETURN
	END
END

IF @TriggerAuditTable IS NULL 
BEGIN 
	SET @TriggerAuditTable = @TriggerTable+'#Audit'
END

IF @TriggerAuditColumnTable IS NULL 
BEGIN 
	SET @TriggerAuditColumnTable = @TriggerTable+'#AuditColumn'
END


--Get Primary Keys for the tables
--We're using the existing #AuditTable so just in case there is a difference, we don't cause any issues
--Cody Schultz 5/5/2022 add varible @PKeysType to store the primary key and its data type.
SET @Query = CONCAT(N'USE ',QUOTENAME(@Database),';
	SELECT @PKeys = STRING_AGG(QUOTENAME(KU.COLUMN_NAME),'','')
	,@PKeysType = STRING_AGG(QUOTENAME(KU.COLUMN_NAME) +'' ''+ C.DATA_TYPE+ISNULL(''(''+CONVERT(NVARCHAR(50),CHARACTER_MAXIMUM_LENGTH)+'')'','''')+ISNULL('' COLLATE ''+COLLATION_NAME,''''),'','')
	,@PKeysInserted = STRING_AGG(''INSERTED.''+QUOTENAME(KU.COLUMN_NAME),'','')
	FROM            INFORMATION_SCHEMA.TABLE_CONSTRAINTS AS TC INNER JOIN
                         INFORMATION_SCHEMA.KEY_COLUMN_USAGE AS KU ON TC.CONSTRAINT_NAME = KU.CONSTRAINT_NAME AND TC.CONSTRAINT_SCHEMA = KU.CONSTRAINT_SCHEMA AND 
                         TC.CONSTRAINT_CATALOG = KU.CONSTRAINT_CATALOG INNER JOIN
                         INFORMATION_SCHEMA.COLUMNS AS C ON C.TABLE_NAME = KU.TABLE_NAME AND C.COLUMN_NAME = KU.COLUMN_NAME AND KU.CONSTRAINT_CATALOG = C.TABLE_CATALOG
	WHERE        (KU.TABLE_NAME = @TriggerTable ) AND TC.CONSTRAINT_TYPE = ''PRIMARY KEY''
	')

EXEC sp_executesql @Query
	,N'@PKeys NVARCHAR(MAX) OUTPUT, @PKeysType NVARCHAR(MAX) OUTPUT, @PKeysInserted NVARCHAR(MAX) OUTPUT,@TriggerTable SYSNAME'
	,@PKeys = @PKeys OUTPUT 
	,@PKeysType = @PKeysType OUTPUT 
	,@PKeysInserted = @PKeysInserted OUTPUT 
	,@TriggerTable = @TriggerTable

--Remove reserved columns from Audit
SET @Query = CONCAT(N'USE ',QUOTENAME(@Database),';
	SELECT @ColumnListIns = STRING_AGG(QUOTENAME(COLUMN_NAME),'','')	
	,@ColumnListSel = STRING_AGG(''I.''+QUOTENAME(COLUMN_NAME),'','')	
	FROM INFORMATION_SCHEMA.COLUMNS
	WHERE TABLE_NAME = @TriggerAuditColumnTable
		AND COLUMN_NAME NOT IN  --Ignore Audit Columns
		(
			 ''boaAuditID''
			,''boaAuditSequence''
			,''boaAuditChange''
		)
		AND COLUMN_NAME NOT IN
		(
			SELECT [Column] 
			FROM Cransoft.dbo.ReservedColumn
		)')

EXEC sp_executesql @Query
	,N'@ColumnListIns NVARCHAR(MAX) OUTPUT,@ColumnListSel NVARCHAR(MAX) OUTPUT,@TriggerAuditColumnTable SYSNAME'
	,@ColumnListIns = @ColumnListIns OUTPUT 
	,@ColumnListSel = @ColumnListSel OUTPUT 
	, @TriggerAuditColumnTable = @TriggerAuditColumnTable


--SET @ColumnListIns = REPLACE(@ColumnListIns,@PKeys,'')
--SET @ColumnListSel = REPLACE(@ColumnListSel,@PKeysInserted,'')
--2022.04.04 Cody Schultz Added to fix comma at the end of the column list
--SET @ColumnList = TRIM('I.,' FROM @ColumnList)
--2022.04.04 Cody Schultz Added to fix double commas in column list
--SET @ColumnList = REPLACE (@ColumnList, ',,', ',')

--Get a list of columns from the #AuditColumns table. The way DSP auditing works is that it only inserts a value into the field that was changed and ignores the ones that weren't
--so we have to code a test for each column to see if there was a change and only insert that column into the audit table if it was changed (only applicable to the UPDATE trigger)

--2022.04.04 Cody Schultz Added additional filter to remove reserved columns
--2022.04.07 Cody Schultz Modified Update trigger code to compare Deleted and Inserted records, if no change then audit value is null.
SET @Query = CONCAT(CAST('' as nVarChar(MAX)),N'USE ',QUOTENAME(@Database),';
	SET @UpdInsertTo = (SELECT CONCAT(''INSERT INTO '',@TriggerAuditColumnTable,'' 
	( 
		[boaAuditID], [boaAuditChange],'', STRING_AGG(CONVERT(NVARCHAR(MAX),QUOTENAME(COLUMN_NAME)),'',''),''
	)'') FROM INFORMATION_SCHEMA.COLUMNS
	WHERE TABLE_NAME = @TriggerAuditColumnTable
		AND COLUMN_NAME NOT IN
		(
			''boaAuditID''
			,''boaAuditSequence''
			,''boaAuditChange''
		)
		AND COLUMN_NAME NOT IN
		(
			SELECT COLUMN_NAME
			FROM INFORMATION_SCHEMA.COLUMNS --Ignore Audit Columns
			WHERE TABLE_NAME = @TriggerAuditTable
				AND COLUMN_NAME NOT IN
				(
					''boaAuditID''
					,''boaAuditProcessToken''
					,''boaAuditDateCreated''
					,''boaAuditUserID''
					,''boaAuditPageID''
					,''boaAuditEvent''
					,''boaAuditSignatureToken''
					,''boaAuditSignatureComment''
				)
		)
		AND COLUMN_NAME NOT IN
		(
			SELECT [Column] 
			FROM Cransoft.dbo.ReservedColumn
		))'
	,CHAR(10),CHAR(9)
	,'SET @UpdColumnListDel = CONCAT(@UpdColumnListDel,'
	,CHAR(10),CHAR(9)
	,'(SELECT CONCAT(''SELECT O.boaAuditID, 0, '', STRING_AGG(CONVERT(NVARCHAR(MAX),CONCAT(''NULLIF(D.'',QUOTENAME(COLUMN_NAME),'', I.'',QUOTENAME(COLUMN_NAME),'')'')),'','')) FROM INFORMATION_SCHEMA.COLUMNS
	WHERE TABLE_NAME = @TriggerAuditColumnTable
		AND COLUMN_NAME NOT IN
		(
			''boaAuditID''
			,''boaAuditSequence''
			,''boaAuditChange''
		)
		AND COLUMN_NAME NOT IN
		(
			SELECT COLUMN_NAME
			FROM INFORMATION_SCHEMA.COLUMNS --Ignore Audit Columns
			WHERE TABLE_NAME = @TriggerAuditTable
				AND COLUMN_NAME NOT IN
				(
					''boaAuditID''
					,''boaAuditProcessToken''
					,''boaAuditDateCreated''
					,''boaAuditUserID''
					,''boaAuditPageID''
					,''boaAuditEvent''
					,''boaAuditSignatureToken''
					,''boaAuditSignatureComment''
				)
		)
		AND COLUMN_NAME NOT IN
		(
			SELECT [Column] 
			FROM Cransoft.dbo.ReservedColumn
		)))'
		,CHAR(10),CHAR(9)
	,'SET @UpdColumnListIns = CONCAT(@UpdColumnListIns,'
	,CHAR(10),CHAR(9)
	,'(SELECT CONCAT(''SELECT O.boaAuditID, 1, '', STRING_AGG(CONVERT(NVARCHAR(MAX),CONCAT(''NULLIF(I.'',QUOTENAME(COLUMN_NAME),'', D.'',QUOTENAME(COLUMN_NAME),'')'')),'','')) FROM INFORMATION_SCHEMA.COLUMNS
	WHERE TABLE_NAME = @TriggerAuditColumnTable
		AND COLUMN_NAME NOT IN
		(
			''boaAuditID''
			,''boaAuditSequence''
			,''boaAuditChange''
		)
		AND COLUMN_NAME NOT IN
		(
			SELECT COLUMN_NAME
			FROM INFORMATION_SCHEMA.COLUMNS --Ignore Audit Columns
			WHERE TABLE_NAME = @TriggerAuditTable
				AND COLUMN_NAME NOT IN
				(
					''boaAuditID''
					,''boaAuditProcessToken''
					,''boaAuditDateCreated''
					,''boaAuditUserID''
					,''boaAuditPageID''
					,''boaAuditEvent''
					,''boaAuditSignatureToken''
					,''boaAuditSignatureComment''
				)
		)
		AND COLUMN_NAME NOT IN
		(
			SELECT [Column] 
			FROM Cransoft.dbo.ReservedColumn
		)))'
		,CHAR(10),CHAR(9)
		,'SET @UpdFrom = CONCAT('' 
	FROM INSERTED I 
	INNER JOIN DELETED D 
		ON '' ,(SELECT STRING_AGG(CONVERT(NVARCHAR(MAX),CONCAT(''I.'',QUOTENAME(COLUMN_NAME),'' = D.'',QUOTENAME(COLUMN_NAME))),'' 
		AND '')+''
	INNER JOIN #InsertOutput O
		ON ''+ STRING_AGG(CONVERT(NVARCHAR(MAX),CONCAT(''I.'',QUOTENAME(COLUMN_NAME),'' = O.'',QUOTENAME(COLUMN_NAME))),'' 
		AND '')
	FROM INFORMATION_SCHEMA.COLUMNS --Ignore Audit Columns
	WHERE TABLE_NAME = @TriggerAuditTable
		AND COLUMN_NAME NOT IN
		(
			 ''boaAuditID''
			,''boaAuditProcessToken''
			,''boaAuditDateCreated''
			,''boaAuditUserID''
			,''boaAuditPageID''
			,''boaAuditEvent''
			,''boaAuditSignatureToken''
			,''boaAuditSignatureComment''
		)))'
		,CHAR(10),CHAR(9)
		,'SET @InsFrom = CONCAT('' 
	FROM INSERTED I 
	INNER JOIN #InsertOutput O 
		ON '' ,(SELECT STRING_AGG(CONVERT(NVARCHAR(MAX),CONCAT(''I.'',QUOTENAME(COLUMN_NAME),'' = O.'',QUOTENAME(COLUMN_NAME))),'' 
		AND '')
	FROM INFORMATION_SCHEMA.COLUMNS --Ignore Audit Columns
	WHERE TABLE_NAME = @TriggerAuditTable
		AND COLUMN_NAME NOT IN
		(
			 ''boaAuditID''
			,''boaAuditProcessToken''
			,''boaAuditDateCreated''
			,''boaAuditUserID''
			,''boaAuditPageID''
			,''boaAuditEvent''
			,''boaAuditSignatureToken''
			,''boaAuditSignatureComment''
		)))'
		,CHAR(10),CHAR(9)
		,'SET @DelFrom = CONCAT('' 
	FROM DELETED I
	INNER JOIN #InsertOutput O 
		ON '' ,(SELECT STRING_AGG(CONVERT(NVARCHAR(MAX),CONCAT(''I.'',QUOTENAME(COLUMN_NAME),'' = O.'',QUOTENAME(COLUMN_NAME))),'' 
		AND '')
	FROM INFORMATION_SCHEMA.COLUMNS --Ignore Audit Columns
	WHERE TABLE_NAME = @TriggerAuditTable
		AND COLUMN_NAME NOT IN
		(
			 ''boaAuditID''
			,''boaAuditProcessToken''
			,''boaAuditDateCreated''
			,''boaAuditUserID''
			,''boaAuditPageID''
			,''boaAuditEvent''
			,''boaAuditSignatureToken''
			,''boaAuditSignatureComment''
		)))')

EXEC sp_executesql @Query
	,N'@UpdColumnListDel NVARCHAR(MAX) OUTPUT,@UpdFrom NVARCHAR(MAX) OUTPUT,@UpdInsertTo NVARCHAR(MAX) OUTPUT,@UpdColumnListIns NVARCHAR(MAX) OUTPUT,@InsFrom NVARCHAR(MAX) OUTPUT, @DelFrom NVARCHAR(MAX) OUTPUT, @TriggerAuditColumnTable SYSNAME,@TriggerAuditTable SYSNAME'
	,@UpdColumnListDel = @UpdColumnListDel OUTPUT 
	,@UpdFrom = @UpdFrom OUTPUT
	,@UpdInsertTo = @UpdInsertTo OUTPUT
	,@UpdColumnListIns = @UpdColumnListIns OUTPUT
	,@InsFrom = @InsFrom OUTPUT
	,@DelFrom = @DelFrom OUTPUT
	,@TriggerAuditColumnTable = @TriggerAuditColumnTable
	,@TriggerAuditTable = @TriggerAuditTable

SET @UpdateTrigger = @UpdInsertTo + CHAR(10) + CHAR(9) + @UpdColumnListDel + @UpdFrom + CHAR(10) + CHAR(9) + CHAR(10) + CHAR(9) + @UpdInsertTo + CHAR(10) + CHAR(9) + @UpdColumnListIns + @UpdFrom



SELECT @InsertTrigger = 'INSERT INTO '+QUOTENAME(@TriggerAuditColumnTable)+'
	(
		[boaAuditID]
		,[boaAuditChange],'+@ColumnListIns+'
	)

	SELECT O.boaAuditID AS [boaAuditID]
		 ,1 AS [boaAuditChange],'+@ColumnListSel+'
	'+@InsFrom

SELECT @DeleteTrigger = 'INSERT INTO '+QUOTENAME(@TriggerAuditColumnTable)+'
	(
		[boaAuditID]
		,[boaAuditChange],'+@ColumnListIns+'
	)

	SELECT O.boaAuditID AS [boaAuditID]
		 ,0 AS [boaAuditChange],'+@ColumnListSel+'
	'+@DelFrom

--Begin trigger definition
--2022.04.04 Cody Schultz changed CREATE TRIGGER to CREATE OR ALTER TRIGGER
--2022.04.29 Cody Schultz changed order of code to exit if UserInterface is the ChangedVia/AddedVia
SELECT @TriggerDefinition = CONCAT('CREATE OR ALTER TRIGGER [dbo].',@TriggerName,'
   ON  [dbo].',QUOTENAME(@TriggerTable),'
   AFTER ',@TriggerType,'
AS
BEGIN
	/* Update the audit tables when a change is made */
	DECLARE @boaAuditProcessToken NVARCHAR(50),@boaAuditDateCreated DATETIME,@boaAuditUserID NVARCHAR(150),@boaAuditEvent NVARCHAR(50),@boaAuditID INT',CASE WHEN @TriggerType = 'Insert' THEN ', @AddedVia NVARCHAR(50), @AddedBy NVARCHAR(50)' WHEN @TriggerType = 'Update' THEN ', @ChangedVia NVARCHAR(50)' WHEN @TriggerType = 'Delete' THEN ', @AddedBy NVARCHAR(50), @ChangedVia NVARCHAR(50)' ELSE '' END,'
	CREATE TABLE #InsertOutput ([boaAuditID] int,'+@PKeysType+')
	SET NOCOUNT ON;
	
	SELECT 
		@boaAuditDateCreated = GETDATE()
		,@boaAuditUserID = ''PageEventRule''		
		,@boaAuditEvent = ''',@TriggerType,'''
		',CASE 
			WHEN @TriggerType = 'Insert' 
				THEN ',@AddedVia = [AddedVia] 
		,@AddedBy = [AddedBy] FROM INSERTED' 
			WHEN @TriggerType = 'Update' 
				THEN ',@ChangedVia = [ChangedVia] FROM INSERTED' 
			WHEN @TriggerType = 'Delete' 
				THEN ',@AddedBy = [AddedBy]
		,@ChangedVia = [ChangedVia] FROM DELETED' 
			ELSE '' END,'
		',CASE 
			WHEN @TriggerType = 'Insert' 
				THEN '
/* Check if update occurs in the user interface and exit trigger if true.  Set the Audit UserID to the AddedVia field to capture stored procedure name*/
	IF (UPDATE([AddedVia]))
	BEGIN
		--User Interface will record inserts in audit, exclude from trigger to avoid duplicates
		IF @AddedVia = ''UserInterface''
			RETURN
		--Excel Import will record inserts in audit, but will not be inserted into Review Role Audit Details page until after ST version 7.5.  If using a version before 7.5, comment out the RETURN command and uncomment out the SET command.
		IF @AddedVia = ''ExcelImport''
			RETURN
			--SET @boaAuditUserID = @AddedBy
	END
	ELSE
		SET @boaAuditUserID = ISNULL(@AddedVia,@boaAuditUserID)' 
			WHEN @TriggerType = 'Update' 
				THEN '
/* Check if update occurs in the user interface and exit trigger if true.  Set the Audit UserID to the ChangedVia field to capture stored procedure name*/
		IF (UPDATE ([LockedOn]))
		RETURN
		-- IF you are using record locking, it records saperate entry for audit table.
	IF (UPDATE([ChangedVia]))
	BEGIN
		--User Interface will record updates in audit, exclude from trigger to avoid duplicates
		IF @ChangedVia = ''UserInterface''
			RETURN
		--Excel Import will record updates in audit, exclude from trigger to avoid duplicates
		IF @ChangedVia = ''ExcelImport''
			RETURN
	END
	ELSE
		SET @boaAuditUserID = ISNULL(@ChangedVia,@boaAuditUserID)'
			WHEN @TriggerType = 'Delete' 
				THEN '
/* Check if update occurs in stored procedure and exit trigger not true.  Set the Audit UserID to the ChangedVia field to capture stored procedure name. Stored Procedure must update record before deleting*/
	IF NOT (@AddedBy = ''PreDelete'')
		RETURN
	ELSE
		SET @boaAuditUserID = ISNULL(@ChangedVia,@boaAuditUserID)' 
			ELSE '' 
			END,'
	
	-- We should be inserting a record into this table if this table is part of the Request. Request is tied to scenario and that scenario is tied to pages. 	
	-- If you just insert in the audit table then the review role aggregate code will break  

	DECLARE @boaAuditPageID UNIQUEIDENTIFIER
	
	SELECT TOP 1 @boaAuditPageID = Page.PageID
	FROM	',CASE WHEN @TriggerType = 'Delete' THEN 'DELETED' ELSE 'INSERTED' END,' AS T 
		INNER JOIN dbo.ttRequest 
			ON T.RequestID = dbo.ttRequest.RequestID 
		INNER JOIN dge.dbo.ttScenarioRoleTask 
			ON dbo.ttRequest.ScenarioID = dge.dbo.ttScenarioRoleTask.ScenarioID 
		INNER JOIN dge.dbo.ttTaskPage 
			ON dge.dbo.ttScenarioRoleTask.TaskID = dge.dbo.ttTaskPage.TaskID 
		INNER JOIN	CranSoft.dbo.Page 
			ON dge.dbo.ttTaskPage.PageID = Page.PageID 	
	WHERE 
		(dge.dbo.ttScenarioRoleTask.ActiveInScenarioRole = 1) 
		AND (Page.[Table] = N''',@TriggerTable,''')  
	
	IF @boaAuditPageID IS NULL
		SELECT TOP 1 @boaAuditPageID = Page.PageID 
		FROM dge.dbo.ttCategory 
			INNER JOIN ztParam 
				ON ztParam.WebAppID = dge.dbo.ttCategory.DefaultWebAppID
			INNER JOIN Cransoft.dbo.Page
				ON Page.PageID = dge.dbo.ttCategory.RequestPageId
		WHERE (Page.[Table] = N''',@TriggerTable,''') AND Page.Active = 1

	IF @boaAuditPageID IS NULL
		SELECT TOP 1 @boaAuditPageID = Page2.PageID 
		FROM dge.dbo.ttCategory 
			INNER JOIN ztParam 
				ON ztParam.WebAppID = dge.dbo.ttCategory.DefaultWebAppID
			INNER JOIN Cransoft.dbo.Page
				ON Page.PageID = dge.dbo.ttCategory.RequestPageId
			INNER JOIN Cransoft.dbo.PageColumn 
				ON PageColumn.PageID = Page.PageID
			INNER JOIN Cransoft.dbo.Page AS Page2
				ON Page2.PageID = PageColumn.LinkToPageID
		WHERE (Page2.[Table] = N''',@TriggerTable,''') AND Page.Active = 1

	IF @boaAuditPageID IS NULL 	
		RETURN

	INSERT INTO ',QUOTENAME(@TriggerAuditTable),'
	(
		[boaAuditProcessToken]
		,[boaAuditDateCreated]
		,[boaAuditUserID]
		,[boaAuditPageID]
		,[boaAuditEvent]
		,'+@PKeys+'
	) OUTPUT INSERTED.[boaAuditID],'+@PKeysInserted+' 
		INTO #InsertOutput ([boaAuditID],'+@PKeys+')

	SELECT
		 NEWID() AS [boaAuditProcessToken]
		,@boaAuditDateCreated AS [boaAuditDateCreated]
		,@boaAuditUserID AS [boaAuditUserID]
		,@boaAuditPageID AS [boaAuditPageID]
		,@boaAuditEvent AS [boaAuditEvent]
		,',@PKeys,'
	FROM    ',CASE WHEN @TriggerType = 'Delete' THEN 'DELETED' ELSE 'INSERTED' END,'	

	',CASE
		WHEN @TriggerType = 'Update' THEN @UpdateTrigger
		WHEN @TriggerType = 'Insert' THEN @InsertTrigger
		WHEN @TriggerType = 'Delete' THEN @DeleteTrigger
	END,CHAR(10),'

	DROP TABLE #InsertOutput
	END'
	)
--EXEC sp_executesql @TriggerDefinition
--2022.04.04 Cody Schultz Utilize webExecuteSQL to execute in different databases
--2022.04.29 Cody Schultz - set up condition to only create triggers when drop triggers parameter is not set.
IF @DropTriggersOnly = 0
	BEGIN
		SELECT CAST(@TriggerDefinition AS XML)
		EXEC dspCommon.dbo.webExecuteSQL @SQL = @TriggerDefinition, @Database = @Database

		UPDATE MC.dbo._AuditTablesWorklist 
		SET [InsTriggerDefinition] = @TriggerDefinition 
		WHERE 
			@TriggerType = 'Insert'
			AND [Database] = @Database											
			AND TableName = @TriggerTable				

		UPDATE MC.dbo._AuditTablesWorklist 
		SET [UpdTriggerDefinition] = @TriggerDefinition 
		WHERE 
			@TriggerType = 'Update'
			AND [Database] = @Database						
			AND TableName = @TriggerTable				

		UPDATE MC.dbo._AuditTablesWorklist 
		SET [DelTriggerDefinition] = @TriggerDefinition 
		WHERE 
			@TriggerType = 'Delete'
			AND [Database] = @Database						
			AND TableName = @TriggerTable				
	END
GO

ALTER AUTHORIZATION ON [dbo].[CreateTriggerForAuditTable] TO  SCHEMA OWNER 
GO

